# Contributor License Agreement

By submitting a contribution (including but not limited to code, documentation,
or other materials) to this project, you agree to the following terms:

## 1. Grant of Copyright License

You grant to the project maintainers and to recipients of software distributed
by the project maintainers a perpetual, worldwide, non-exclusive, no-charge,
royalty-free, irrevocable copyright license to reproduce, prepare derivative
works of, publicly display, publicly perform, sublicense, and distribute your
contributions and such derivative works.

## 2. Grant of Patent License

You grant to the project maintainers and to recipients of software distributed
by the project maintainers a perpetual, worldwide, non-exclusive, no-charge,
royalty-free, irrevocable patent license to make, have made, use, offer to sell,
sell, import, and otherwise transfer the work, where such license applies only
to those patent claims licensable by you that are necessarily infringed by your
contribution alone or by combination of your contribution with the project to
which it was submitted.

## 3. Right to Grant

You represent that you are legally entitled to grant the above licenses. If your
employer has rights to intellectual property that you create, you represent that
you have received permission to make contributions on behalf of that employer,
or that your employer has waived such rights for your contributions to this
project.

## 4. Original Work

You represent that each of your contributions is your original creation. You
represent that your contribution submissions include complete details of any
third-party license or other restriction (including, but not limited to, related
patents and trademarks) of which you are aware and which are associated with any
part of your contributions.

## 5. Re-licensing

You acknowledge and agree that the project maintainers may re-license the
project (including your contributions) under any license terms they see fit,
including proprietary licenses. This right is granted to ensure the long-term
viability and flexibility of the project.

## 6. No Obligation

You understand that the decision to include your contribution in any project or
source repository is entirely at the discretion of the project maintainers, and
this agreement does not obligate the project maintainers to use or include your
contribution.

## 7. Support

You are not expected to provide support for your contributions, except to the
extent you desire to provide support. You may provide support for free, for a
fee, or not at all.

## How to Sign

By opening a pull request or otherwise submitting a contribution to this
project, you indicate that you have read this Contributor License Agreement and
agree to its terms.
